@@ -12,9 +12,10 @@ class Protocol:
 
 
 class UploadConfiguration(Deserializable):
-    def __init__(self, upload_url: str):
+    def __init__(self, upload_url: str, upload_token: str = None):
         self.upload_url = upload_url
+        self.upload_token = upload_token
 
     @classmethod
     def deserialize(cls, data: dict) -> UploadConfiguration:
-        return UploadConfiguration(data['uploadUrl'])
+        return UploadConfiguration(data['uploadUrl'], data.get('uploadToken'))
